pub struct SessionMutatorExt(pub Arc<dyn SessionMutator>);Expand description
Type-keyed wrapper installed on the tool context by hosted presets.
Core carries the generic extension bag but does not name this service.
Tuple Fields
0: Arc<dyn SessionMutator>Trait Implementations
Sourceimpl Clone for SessionMutatorExt
impl Clone for SessionMutatorExt
Sourcefn clone(&self) -> SessionMutatorExt
fn clone(&self) -> SessionMutatorExt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl !RefUnwindSafe for SessionMutatorExt
impl !UnwindSafe for SessionMutatorExt
impl Freeze for SessionMutatorExt
impl Send for SessionMutatorExt
impl Sync for SessionMutatorExt
impl Unpin for SessionMutatorExt
impl UnsafeUnpin for SessionMutatorExt